==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/resin/src/com/caucho/ejb/session/StatefulObject.java <==
/*
 * Copyright (c) 1998-2008 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.ejb.session;

import com.caucho.ejb.AbstractEJBObject;
import com.caucho.ejb.AbstractServer;
import com.caucho.ejb.protocol.ObjectSkeletonWrapper;

import javax.ejb.Handle;
import java.io.ObjectStreamException;
import java.io.Serializable;
import java.rmi.RemoteException;
import javax.ejb.*;

/**
 * Abstract base class for a stateful session object
 */
abstract public class StatefulObject extends AbstractEJBObject
  implements Serializable
{
  private String _primaryKey;
  
  /**
   * Returns the server.
   */
  public AbstractServer getServer()
  {
    return getStatefulServer();
  }

  /**
   * Returns the server which owns this bean.
   */
  @Override
  public AbstractServer __caucho_getServer()
  {
    return getStatefulServer();
  }

  public abstract StatefulServer getStatefulServer();

  public String __caucho_getId()
  {
    if (_primaryKey == null)
      _primaryKey = getStatefulServer().createSessionKey(this);
    
    return _primaryKey;
  }

  //
  // EJB 2.1 methods
  //

  /**
   * Returns the primary key
   */
  public Object getPrimaryKey()
  {
    return __caucho_getId();
  }

  /**
   * Returns the EJBHome
   */
  public EJBHome getEJBHome()
  {
    return getServer().getEJBHome();
  }

  /**
   * Returns the EJBLocalHome
   */
  public EJBLocalHome getEJBLocalHome()
  {
    return getServer().getEJBLocalHome();
  }

  /**
   * Returns the handle.
   */
  public Handle getHandle()
  {
    return getServer().getHandleEncoder().createHandle(__caucho_getId());
  }

  /**
   * Returns true if the two objects are identical.
   */
  public boolean isIdentical(EJBObject obj) throws RemoteException
  {
    return getHandle().equals(obj.getHandle());
  }

  /**
   * Returns true if the two objects are identical.
   */
  public boolean isIdentical(EJBLocalObject obj)
  {
    return this == obj;
  }

  public void remove()
    throws javax.ejb.RemoveException
  {
  }

  /**
   * Serialize the HomeSkeletonWrapper in place of this object.
   *
   * @return the matching skeleton wrapper.
   */
  public Object writeReplace() throws ObjectStreamException
  {
    return new ObjectSkeletonWrapper(getHandle());
  }
}

==> resin-4.0.66-src.tar.gz: resin-4.0.66/modules/resin/src/com/caucho/ejb/session/StatefulObject.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.ejb.session;

import java.io.ObjectStreamException;
import java.io.Serializable;

import com.caucho.ejb.server.AbstractEjbBeanManager;

/**
 * Abstract base class for a stateful session object
 */
abstract public class StatefulObject
  implements Serializable
{
  private String _primaryKey;
  
  /**
   * Returns the server.
   */
  public AbstractEjbBeanManager getServer()
  {
    return getStatefulServer();
  }

  /**
   * Returns the server which owns this bean.
   */
  public AbstractEjbBeanManager __caucho_getServer()
  {
    return getStatefulServer();
  }

  public abstract StatefulManager getStatefulServer();

  public String __caucho_getId()
  {
    if (_primaryKey == null)
      _primaryKey = getStatefulServer().generateKey();
    
    return _primaryKey;
  }

  //
  // EJB 2.1 methods
  //

  /**
   * Returns the primary key
   */
  public Object getPrimaryKey()
  {
    return __caucho_getId();
  }

  /**
   * Serialize the HomeSkeletonWrapper in place of this object.
   *
   * @return the matching skeleton wrapper.
   */
  public Object writeReplace() throws ObjectStreamException
  {
    throw new UnsupportedOperationException(getClass().getName());
    // return new ObjectSkeletonWrapper(getHandle());
  }
}
